@@ -50,7 +50,7 @@ class VoidCallback;
 
 class NotificationCenter : public RefCounted<NotificationCenter>, public ActiveDOMObject {
 public:
-    static PassRef<NotificationCenter> create(ScriptExecutionContext*, NotificationClient*);
+    static Ref<NotificationCenter> create(ScriptExecutionContext*, NotificationClient*);
 
 #if ENABLE(LEGACY_NOTIFICATIONS)
     PassRefPtr<Notification> createNotification(const String& iconURI, const String& title, const String& body, ExceptionCode& ec)
@@ -75,6 +75,7 @@ private:
 
     // ActiveDOMObject
     virtual void stop() override;
+    virtual const char* activeDOMObjectName() const override { return "NotificationCenter"; }
 
     class NotificationRequestCallback : public RefCounted<NotificationRequestCallback> {
     public:
