@@ -187,8 +187,9 @@ bool ScriptExecutionContext::canSuspendActiveDOMObjects(Vector<ActiveDOMObject*>
 
     // We assume that m_activeDOMObjects will not change during iteration: canSuspend
     // functions should not add new active DOM objects, nor execute arbitrary JavaScript.
-    // An ASSERT or RELEASE_ASSERT will fire if this happens, but it's important to code
+    // An ASSERT_WITH_SECURITY_IMPLICATION or RELEASE_ASSERT will fire if this happens, but it's important to code
     // canSuspend functions so it will not happen!
+    NoEventDispatchAssertion assertNoEventDispatch;
     for (auto* activeDOMObject : m_activeDOMObjects) {
         if (!activeDOMObject->canSuspend()) {
             canSuspend = false;
@@ -225,7 +226,7 @@ void ScriptExecutionContext::suspendActiveDOMObjects(ActiveDOMObject::ReasonForS
 
     // We assume that m_activeDOMObjects will not change during iteration: suspend
     // functions should not add new active DOM objects, nor execute arbitrary JavaScript.
-    // An ASSERT or RELEASE_ASSERT will fire if this happens, but it's important to code
+    // An ASSERT_WITH_SECURITY_IMPLICATION or RELEASE_ASSERT will fire if this happens, but it's important to code
     // suspend functions so it will not happen!
     for (auto* activeDOMObject : m_activeDOMObjects)
         activeDOMObject->suspend(why);
@@ -254,7 +255,7 @@ void ScriptExecutionContext::resumeActiveDOMObjects(ActiveDOMObject::ReasonForSu
 
     // We assume that m_activeDOMObjects will not change during iteration: resume
     // functions should not add new active DOM objects, nor execute arbitrary JavaScript.
-    // An ASSERT or RELEASE_ASSERT will fire if this happens, but it's important to code
+    // An ASSERT_WITH_SECURITY_IMPLICATION or RELEASE_ASSERT will fire if this happens, but it's important to code
     // resume functions so it will not happen!
     for (auto* activeDOMObject : m_activeDOMObjects)
         activeDOMObject->resume();
@@ -281,7 +282,7 @@ void ScriptExecutionContext::stopActiveDOMObjects()
 
     // We assume that new objects will not be added to m_activeDOMObjects during iteration:
     // stop functions should not add new active DOM objects, nor execute arbitrary JavaScript.
-    // A RELEASE_ASSERT will fire if this happens, but it's important to code stop functions
+    // An ASSERT_WITH_SECURITY_IMPLICATION or RELEASE_ASSERT will fire if this happens, but it's important to code stop functions
     // so it will not happen!
     for (auto* activeDOMObject : possibleActiveDOMObjects) {
         // Check if this object was deleted already. If so, just skip it.
@@ -323,7 +324,7 @@ void ScriptExecutionContext::didCreateActiveDOMObject(ActiveDOMObject& activeDOM
 
 void ScriptExecutionContext::willDestroyActiveDOMObject(ActiveDOMObject& activeDOMObject)
 {
-    ASSERT(!m_activeDOMObjectRemovalForbidden);
+    ASSERT_WITH_SECURITY_IMPLICATION(!m_activeDOMObjectRemovalForbidden);
     m_activeDOMObjects.remove(&activeDOMObject);
 }
 
