@@ -39,12 +39,13 @@
 
 namespace WebCore {
 
-class MediaConstraints;
 class MediaStreamSource;
-class RTCConfiguration;
+class RTCConfigurationPrivate;
 class RTCDTMFSenderHandler;
 class RTCDataChannelHandler;
 class RTCIceCandidateDescriptor;
+class RTCOfferOptionsPrivate;
+class RTCOfferAnswerOptionsPrivate;
 class RTCPeerConnectionHandler;
 class RTCPeerConnectionHandlerClient;
 class RTCSessionDescriptionDescriptor;
@@ -72,7 +73,7 @@ typedef std::unique_ptr<RTCPeerConnectionHandler> (*CreatePeerConnectionHandler)
 
 class RTCPeerConnectionHandler {
 public:
-    static CreatePeerConnectionHandler create;
+    WEBCORE_EXPORT static CreatePeerConnectionHandler create;
     virtual ~RTCPeerConnectionHandler() { }
 
     static const AtomicString& incompatibleConstraintsErrorName();
@@ -80,17 +81,17 @@ public:
     static const AtomicString& incompatibleSessionDescriptionErrorName();
     static const AtomicString& internalErrorName();
 
-    virtual bool initialize(PassRefPtr<RTCConfiguration>, PassRefPtr<MediaConstraints>) = 0;
+    virtual bool initialize(PassRefPtr<RTCConfigurationPrivate>) = 0;
 
-    virtual void createOffer(PassRefPtr<RTCSessionDescriptionRequest>, PassRefPtr<MediaConstraints>) = 0;
-    virtual void createAnswer(PassRefPtr<RTCSessionDescriptionRequest>, PassRefPtr<MediaConstraints>) = 0;
+    virtual void createOffer(PassRefPtr<RTCSessionDescriptionRequest>, PassRefPtr<RTCOfferOptionsPrivate>) = 0;
+    virtual void createAnswer(PassRefPtr<RTCSessionDescriptionRequest>, PassRefPtr<RTCOfferAnswerOptionsPrivate>) = 0;
     virtual void setLocalDescription(PassRefPtr<RTCVoidRequest>, PassRefPtr<RTCSessionDescriptionDescriptor>) = 0;
     virtual void setRemoteDescription(PassRefPtr<RTCVoidRequest>, PassRefPtr<RTCSessionDescriptionDescriptor>) = 0;
     virtual PassRefPtr<RTCSessionDescriptionDescriptor> localDescription() = 0;
     virtual PassRefPtr<RTCSessionDescriptionDescriptor> remoteDescription() = 0;
-    virtual bool updateIce(PassRefPtr<RTCConfiguration>, PassRefPtr<MediaConstraints>) = 0;
+    virtual bool updateIce(PassRefPtr<RTCConfigurationPrivate>) = 0;
     virtual bool addIceCandidate(PassRefPtr<RTCVoidRequest>, PassRefPtr<RTCIceCandidateDescriptor>) = 0;
-    virtual bool addStream(PassRefPtr<MediaStreamPrivate>, PassRefPtr<MediaConstraints>) = 0;
+    virtual bool addStream(PassRefPtr<MediaStreamPrivate>) = 0;
     virtual void removeStream(PassRefPtr<MediaStreamPrivate>) = 0;
     virtual void getStats(PassRefPtr<RTCStatsRequest>) = 0;
     virtual std::unique_ptr<RTCDataChannelHandler> createDataChannel(const String& label, const RTCDataChannelInit&) = 0;
