@@ -37,7 +37,7 @@
 #include <CFNetwork/CFURLConnectionPriv.h>
 #endif
 
-#if USE(WININET) || (USE(CURL) && PLATFORM(WIN))
+#if USE(CURL) && PLATFORM(WIN)
 #include <winsock2.h>
 #include <windows.h>
 #endif
@@ -86,16 +86,6 @@ namespace WebCore {
 #if USE(CFNETWORK)
             , m_currentRequest(request)
 #endif
-#if USE(WININET)
-            , m_fileLoadTimer(loader, &ResourceHandle::fileLoadTimer)
-            , m_internetHandle(0)
-            , m_connectHandle(0)
-            , m_requestHandle(0)
-            , m_sentEndRequest(false)
-            , m_bytesRemainingToWrite(0)
-            , m_loadSynchronously(false)
-            , m_hasReceivedResponse(false)
-#endif
 #if USE(CURL)
             , m_handle(0)
             , m_url(0)
@@ -115,7 +105,6 @@ namespace WebCore {
 #endif
 #if PLATFORM(COCOA)
             , m_startWhenScheduled(false)
-            , m_needsSiteSpecificQuirks(false)
             , m_currentMacChallenge(nil)
 #endif
             , m_scheduledFailureType(ResourceHandle::NoFailure)
@@ -157,23 +146,10 @@ namespace WebCore {
 #endif
 #if PLATFORM(COCOA)
         bool m_startWhenScheduled;
-        bool m_needsSiteSpecificQuirks;
 #endif
 #if PLATFORM(COCOA) || USE(CFNETWORK)
         RetainPtr<CFURLStorageSessionRef> m_storageSession;
 #endif
-#if USE(WININET)
-        Timer m_fileLoadTimer;
-        HINTERNET m_internetHandle;
-        HINTERNET m_connectHandle;
-        HINTERNET m_requestHandle;
-        bool m_sentEndRequest;
-        Vector<char> m_formData;
-        size_t m_bytesRemainingToWrite;
-        bool m_loadSynchronously;
-        bool m_hasReceivedResponse;
-        String m_redirectUrl;
-#endif
 #if USE(CURL)
         CURL* m_handle;
         char* m_url;
